@@ -514,8 +514,12 @@ def sigProfilerExtractor(input_type,
             mtypes = ["ID83"]
         elif mtypes[0] == "48":
             mtypes = ["CNV48"]
-        else:
+        elif mtypes[0]=="32":
+            mtypes = ["SV32"]
+        elif mtypes[0]=="96" or "288" or "384" or "1536":
             mtypes = ["SBS"+mtypes[0]]
+        else:
+            mtypes = ["CH"+mtypes[0]]
         
     ###############################################################################################################
     
@@ -600,27 +604,15 @@ def sigProfilerExtractor(input_type,
             
         #project_name = project.split("/")[-1]
         data = datadump.SigProfilerMatrixGeneratorFunc(project_name, refgen, project, exome=exome,  bed_file=None, chrom_based=False, plot=False, gs=False)
-        
+        print(data.keys())
         
         
         
         # Selecting the mutation types    
         if mtype == ["default"]:
-            if set(["96", "DINUC", "ID"]).issubset(data):  
-                mtypes = ["SBS96", "DBS78", "ID83"] 
-            elif set(["96", "DINUC"]).issubset(data): 
-                mtypes = ["SBS96", "DBS78"]
-            elif set(["ID"]).issubset(data):            
-                mtypes = ["ID83"]    
-        
+            mtypes = ["SBS96", "DBS78", "ID83"] 
         elif mtype == "default":
-            if set(["96", "DINUC", "ID"]).issubset(data):  
-                mtypes = ["SBS96", "DBS78", "ID83"] 
-            elif set(["96", "DINUC"]).issubset(data): 
-                mtypes = ["SBS96", "DBS78"]
-            elif set(["ID"]).issubset(data):            
-                mtypes = ["ID83"]
-          
+            mtypes = ["SBS96", "DBS78", "ID83"] 
         else:
             #mkeys = data.keys()
             mtype = mtype.upper()
@@ -667,14 +659,26 @@ def sigProfilerExtractor(input_type,
             m = "ID"
         elif m.startswith("CNV"):
             m="CNV"
+        elif m.startswith("SV"):
+            m="SV"
         
         # Determine the types of mutation which will be needed for exporting and copying the files
-        if not (m=="DINUC" or m.startswith("DBS") or m.startswith("ID") or m.startswith("CNV")):
+        if not (m=="DINUC" or m.startswith("DBS") or m.startswith("ID") or m.startswith("CNV") or m.startswith("SV")):
             
             if m.startswith("SBS"):
                 mutation_type = m
+            elif m.startswith("96" or "288" or "384" or "1536"):
+                mutation_type="SBS"+m
+            elif m.startswith("78"): 
+                mutation_type="DBS78"
+            elif m.startswith("83"):
+                mutation_type="ID83"
+            elif m.startswith("48"):
+                mutation_type="CNV48"
+            elif m.startswith("32"):
+                mutation_type="SV32"
             else:
-                mutation_type = "SBS"+m
+                mutation_type = "CH"+m
             
         else:
             if m == "DINUC" or m.startswith("DBS"):
@@ -683,6 +687,8 @@ def sigProfilerExtractor(input_type,
                 mutation_type = "ID83"
             elif m== "CNV" or m.startswith("CNV"):
                 mutation_type = "CNV48"
+            elif m== "SV" or m.startswith("SV"):
+                mutation_type = "SV32"
                 
        
             
@@ -691,10 +697,13 @@ def sigProfilerExtractor(input_type,
             try: 
                 
                 genomes = pd.DataFrame(data[m])
-            except: 
-                raise Exception("Please pass valid mutation types seperated by comma with no space. Carefully check (using SigProfilerMatrixGenerator)"\
-                                 "what mutation contexts should be generated by your VCF files. Also please use the uppercase characters")
-            
+            except KeyError: 
+                sysdata = open(out_put+"/JOB_METADATA.txt", "a")
+                sysdata.write("Context {} is not available in the current vcf files".format(m)+"\n")
+                print("Context {} is not available in the current vcf files".format(m))
+                sysdata.close()
+                
+                continue
             #check if the genome is a nonzero matrix
             shape= genomes.shape
             if shape==(0,0):
